@@ -139,6 +139,8 @@ def _format_number(num, n_signif_figures, max_width):
     """
     if max_width < 6:
         raise NotImplementedError("Guaranteed formatting in fewer than 6 characters not supported.")
+    if math.isnan(num):
+        return str(num)
     # add 0.5 to prevent log(0) errors; only affects n_digits calculation for num > 0
     n_digits = lambda num: math.floor(math.log10(abs(num) + 0.5)) + 1
     if abs(num) > 10**-n_signif_figures and n_digits(num) <= max_width - n_signif_figures:
@@ -160,7 +162,7 @@ def _summary(fit, pars=None, probs=None, **kwargs):
 
     Parameters
     ----------
-    fit : stanfit4model object
+    fit : StanFit4Model object
     pars : str or sequence of str, optional
         Parameter names. By default use all parameters
     probs : sequence of float, optional
@@ -360,8 +362,8 @@ def _split_data(data):
         elif np.issubdtype(np.asarray(v).dtype, float):
             data_r.update({k.encode('utf-8'): np.asarray(v, dtype=float)})
         else:
-            msg = "Variable {} neither int nor float (dtype: {})"
-            raise ValueError(msg.format(k, v.dtype))
+            msg = "Variable {} is neither int nor float nor list/array thereof"
+            raise ValueError(msg.format(k))
     return data_r, data_i
 
 
@@ -826,7 +828,7 @@ def _get_kept_samples(n, sim):
     ----------
     n : int
     sim : dict
-        A dictionary tied to a StanFit4<model> instance.
+        A dictionary tied to a StanFit4Model instance.
 
     Returns
     -------
@@ -845,7 +847,7 @@ def _get_samples(n, sim, inc_warmup=True):
     ----------
     n : int
     sim : dict
-        A dictionary tied to a StanFit4<model> instance.
+        A dictionary tied to a StanFit4Model instance.
 
     Returns
     -------
