@@ -263,8 +263,6 @@ class StanModel:
             os.path.join(pystan_dir, "stan/lib/boost_1.54.0"),
             np.get_include(),
         ]
-        library_dirs = [os.path.join(pystan_dir)]
-        libraries = ['stan']
 
         if not os.path.exists(lib_dir):
             os.makedirs(lib_dir)
@@ -288,8 +286,6 @@ class StanModel:
                               language="c++",
                               sources=[pyx_file],
                               include_dirs=include_dirs,
-                              library_dirs=library_dirs,
-                              libraries=libraries,
                               extra_compile_args=extra_compile_args)
 
         cython_include_dirs = ['.', pystan_dir]
@@ -313,7 +309,7 @@ class StanModel:
                 os.dup2(orig_stderr, sys.stderr.fileno())
 
         self.module = load_module(module_name, lib_dir)
-        self.fit_class = getattr(self.module, "StanFit4" + self.model_cppname)
+        self.fit_class = getattr(self.module, "StanFit4Model")
 
     def __str__(self):
         # NOTE: returns unicode even for Python 2.7, implements_to_string
@@ -322,7 +318,9 @@ class StanModel:
         return s.format(self.model_name, self.model_code)
 
     def __del__(self):
-        shutil.rmtree(self._temp_dir, ignore_errors=True)
+        _temp_dir = getattr(self, '_temp_dir', None)
+        if _temp_dir:
+            shutil.rmtree(_temp_dir, ignore_errors=True)
 
     def show(self):
         print(self)
@@ -344,10 +342,9 @@ class StanModel:
         """
         state = self.__dict__.copy()
         if state['save_dso']:
-            module_filename = state['module'].__file__
-            state['module_filename'] = module_filename
+            state['module_filename'] = state['module'].__file__
             state['module_name'] = state['module'].__name__
-            with io.open(module_filename, 'rb') as f:
+            with io.open(state['module_filename'], 'rb') as f:
                 state['module_bytes'] = f.read()
         del state['module']
         del state['fit_class']
@@ -373,7 +370,7 @@ class StanModel:
                 f.write(module_bytes)
             try:
                 self.module = load_module(module_name, lib_dir)
-                self.fit_class = getattr(self.module, "StanFit4" + self.model_cppname)
+                self.fit_class = getattr(self.module, "StanFit4Model")
             except Exception as e:
                 logger.warning(e)
                 logger.warning("Something went wrong while unpickling "
@@ -624,7 +621,7 @@ class StanModel:
 
         Returns
         -------
-        fit : StanFit4<model_name>
+        fit : StanFit4Model
             Instance containing the fitted results.
 
         Other parameters
