@@ -1,9 +1,10 @@
-#ifndef __STAN__AGRAD__FWD__FUNCTIONS__ASIN_HPP__
-#define __STAN__AGRAD__FWD__FUNCTIONS__ASIN_HPP__
+#ifndef STAN__AGRAD__FWD__FUNCTIONS__ASIN_HPP
+#define STAN__AGRAD__FWD__FUNCTIONS__ASIN_HPP
 
 #include <stan/agrad/fwd/fvar.hpp>
 #include <stan/meta/traits.hpp>
 #include <stan/math/functions/square.hpp>
+#include <math.h>
 
 namespace stan {
 
@@ -13,7 +14,7 @@ namespace stan {
     inline
     fvar<T>
     asin(const fvar<T>& x) {
-      using std::asin;
+      using ::asin;
       using std::sqrt;
       using stan::math::square;
       return fvar<T>(asin(x.val_), x.d_ / sqrt(1 - square(x.val_)));
