@@ -1,9 +1,12 @@
-#ifndef __STAN__AGRAD__FWD__FUNCTIONS__FABS_HPP__
-#define __STAN__AGRAD__FWD__FUNCTIONS__FABS_HPP__
+#ifndef STAN__AGRAD__FWD__FUNCTIONS__FABS_HPP
+#define STAN__AGRAD__FWD__FUNCTIONS__FABS_HPP
 
 #include <stan/agrad/fwd/fvar.hpp>
 #include <stan/meta/traits.hpp>
 #include <stan/math/constants.hpp>
+#include <stan/math/functions/value_of.hpp>
+#include <math.h>
+#include <stan/meta/likely.hpp>
 
 namespace stan {
 
@@ -14,14 +17,17 @@ namespace stan {
     fvar<T>
     fabs(const fvar<T>& x) {
       using stan::math::NOT_A_NUMBER;
-      if (x.val_ > 0.0)
+      using ::fabs;
+      using stan::math::value_of;
+
+      if (unlikely(boost::math::isnan(value_of(x.val_))))
+        return fvar<T>(fabs(x.val_),stan::math::NOT_A_NUMBER);
+      else if (x.val_ > 0.0)
         return x;
       else if (x.val_ < 0.0)
         return fvar<T>(-x.val_, -x.d_);
-      else if (x.val_ == 0.0)
-        return fvar<T>(0, 0);
       else
-        return fvar<T>(NOT_A_NUMBER,NOT_A_NUMBER);
+        return fvar<T>(0, 0);
     }
   }
 }
