@@ -1,5 +1,5 @@
-#ifndef __STAN__AGRAD__FWD__MATRIX__INVERSE_HPP__
-#define __STAN__AGRAD__FWD__MATRIX__INVERSE_HPP__
+#ifndef STAN__AGRAD__FWD__MATRIX__INVERSE_HPP
+#define STAN__AGRAD__FWD__MATRIX__INVERSE_HPP
 
 #include <vector>
 #include <boost/math/tools/promotion.hpp>
@@ -9,9 +9,6 @@
 #include <stan/agrad/fwd/operators/operator_multiplication.hpp>
 #include <stan/agrad/fwd/matrix/to_fvar.hpp>
 #include <stan/agrad/fwd/matrix/multiply.hpp>
-#include <stan/agrad/rev/matrix/multiply.hpp>
-#include <stan/agrad/rev/operators.hpp>
-#include <stan/agrad/rev/functions/abs.hpp>
 #include <stan/math/matrix/inverse.hpp>
 #include <stan/math/error_handling/matrix/check_square.hpp>
 
