@@ -1,5 +1,5 @@
-#ifndef __STAN__AGRAD__REV__MATRIX__EIGEN_NUMTRAITS_HPP__
-#define __STAN__AGRAD__REV__MATRIX__EIGEN_NUMTRAITS_HPP__
+#ifndef STAN__AGRAD__REV__MATRIX__EIGEN_NUMTRAITS_HPP
+#define STAN__AGRAD__REV__MATRIX__EIGEN_NUMTRAITS_HPP
 
 #include <limits>
 #include <stan/math/matrix/Eigen.hpp>
