@@ -1,5 +1,5 @@
-#ifndef __STAN__AGRAD__REV__MATRIX__LDLT_FACTOR_HPP__
-#define __STAN__AGRAD__REV__MATRIX__LDLT_FACTOR_HPP__
+#ifndef STAN__AGRAD__REV__MATRIX__LDLT_FACTOR_HPP
+#define STAN__AGRAD__REV__MATRIX__LDLT_FACTOR_HPP
 
 #include <stan/agrad/rev/var.hpp>
 #include <stan/agrad/rev/matrix/LDLT_alloc.hpp>
