@@ -1,5 +1,5 @@
-#ifndef __STAN__GM__PARSER__VAR_DECLS_GRAMMAR_DEF__HPP__
-#define __STAN__GM__PARSER__VAR_DECLS_GRAMMAR_DEF__HPP__
+#ifndef STAN__GM__PARSER__VAR_DECLS_GRAMMAR_DEF__HPP
+#define STAN__GM__PARSER__VAR_DECLS_GRAMMAR_DEF__HPP
 
 #include <boost/spirit/include/qi.hpp>
 // FIXME: get rid of unused include
@@ -207,6 +207,10 @@ namespace stan {
         }
         return is_data;
       }
+      bool operator()(const integrate_ode& x) const {
+        return boost::apply_visitor(*this, x.y0_.expr_)
+          && boost::apply_visitor(*this, x.theta_.expr_);
+      }
       bool operator()(const fun& x) const {
         for (size_t i = 0; i < x.args_.size(); ++i)
           if (!boost::apply_visitor(*this,x.args_[i].expr_))
@@ -571,10 +575,12 @@ namespace stan {
 
 
     struct validate_int_data_expr {
-      template <typename T1, typename T2, typename T3>
-      struct result { typedef bool type; };
+      template <typename T1, typename T2, typename T3, typename T4, typename T5>
+      struct result { typedef void type; };
 
-      bool operator()(const expression& expr,
+      void operator()(const expression& expr,
+                      int var_origin,
+                      bool& pass,
                       variable_map& var_map,
                       std::stringstream& error_msgs) const {
         if (!expr.expression_type().is_primitive_int()) {
@@ -582,11 +588,16 @@ namespace stan {
                      << " found type=" 
                      << expr.expression_type() 
                      << std::endl;
-          return false;
+          pass = false;
+        } else if (var_origin != local_origin) {
+          data_only_expression vis(error_msgs,var_map);
+          bool only_data_dimensions = boost::apply_visitor(vis,expr.expr_);
+          pass = only_data_dimensions;
+        } else {
+          // don't need to check data vs. parameter in dimensions for
+          // local variable declarations
+          pass = true;
         }
-        data_only_expression vis(error_msgs,var_map);
-        bool only_data_dimensions = boost::apply_visitor(vis,expr.expr_);
-        return only_data_dimensions;
       }
     };
     boost::phoenix::function<validate_int_data_expr> validate_int_data_expr_f;
@@ -739,7 +750,8 @@ namespace stan {
 
       vector_decl_r.name("vector declaration");
       vector_decl_r 
-        %= lit("vector")
+        %= ( lit("vector")
+             >> no_skip[!char_("a-zA-Z0-9_")] )
         > -range_brackets_double_r(_r1)
         > lit('[')
         > expression_g(_r1)
@@ -751,7 +763,8 @@ namespace stan {
 
       row_vector_decl_r.name("row vector declaration");
       row_vector_decl_r 
-        %= lit("row_vector")
+        %= ( lit("row_vector")
+             >> no_skip[!char_("a-zA-Z0-9_")] )
         > -range_brackets_double_r(_r1)
         > lit('[')
         > expression_g(_r1)
@@ -763,7 +776,8 @@ namespace stan {
 
       matrix_decl_r.name("matrix declaration");
       matrix_decl_r 
-        %= lit("matrix")
+        %= ( lit("matrix")
+             >> no_skip[!char_("a-zA-Z0-9_")] )
         > -range_brackets_double_r(_r1)
         > lit('[')
         > expression_g(_r1)
@@ -778,7 +792,8 @@ namespace stan {
 
       unit_vector_decl_r.name("unit_vector declaration");
       unit_vector_decl_r 
-        %= lit("unit_vector")
+        %= ( lit("unit_vector")
+             >> no_skip[!char_("a-zA-Z0-9_")] )
         > lit('[')
         > expression_g(_r1)
           [validate_int_expr_f(_1,_pass,boost::phoenix::ref(error_msgs_))]
@@ -789,7 +804,8 @@ namespace stan {
 
       simplex_decl_r.name("simplex declaration");
       simplex_decl_r 
-        %= lit("simplex")
+        %= ( lit("simplex")
+             >> no_skip[!char_("a-zA-Z0-9_")] )
         > lit('[')
         > expression_g(_r1)
           [validate_int_expr_f(_1,_pass,boost::phoenix::ref(error_msgs_))]
@@ -800,7 +816,8 @@ namespace stan {
 
       ordered_decl_r.name("ordered declaration");
       ordered_decl_r 
-        %= lit("ordered")
+        %= ( lit("ordered")
+             >> no_skip[!char_("a-zA-Z0-9_")] )
         > lit('[')
         > expression_g(_r1)
           [validate_int_expr_f(_1,_pass,boost::phoenix::ref(error_msgs_))]
@@ -811,7 +828,8 @@ namespace stan {
 
       positive_ordered_decl_r.name("positive_ordered declaration");
       positive_ordered_decl_r 
-        %= lit("positive_ordered")
+        %= ( lit("positive_ordered")
+             >> no_skip[!char_("a-zA-Z0-9_")] )
         > lit('[')
         > expression_g(_r1)
           [validate_int_expr_f(_1,_pass,boost::phoenix::ref(error_msgs_))]
@@ -822,7 +840,8 @@ namespace stan {
 
       cholesky_factor_decl_r.name("cholesky factor for symmetric, positive-def declaration");
       cholesky_factor_decl_r 
-        %= lit("cholesky_factor_cov") 
+        %= ( lit("cholesky_factor_cov") 
+             >> no_skip[!char_("a-zA-Z0-9_")] )
         > lit('[')
         > expression_g(_r1)
           [validate_int_expr_f(_1,_pass,boost::phoenix::ref(error_msgs_))]
@@ -839,7 +858,8 @@ namespace stan {
 
       cholesky_corr_decl_r.name("cholesky factor for correlation matrix declaration");
       cholesky_corr_decl_r 
-        %= lit("cholesky_factor_corr")
+        %= ( lit("cholesky_factor_corr")
+             >> no_skip[!char_("a-zA-Z0-9_")] )
         > lit('[')
         > expression_g(_r1)
           [validate_int_expr_f(_1,_pass,boost::phoenix::ref(error_msgs_))]
@@ -850,7 +870,8 @@ namespace stan {
 
       cov_matrix_decl_r.name("covariance matrix declaration");
       cov_matrix_decl_r 
-        %= lit("cov_matrix")
+        %= ( lit("cov_matrix")
+             >> no_skip[!char_("a-zA-Z0-9_")] )
         > lit('[')
         > expression_g(_r1)
           [validate_int_expr_f(_1,_pass,boost::phoenix::ref(error_msgs_))]
@@ -861,7 +882,8 @@ namespace stan {
 
       corr_matrix_decl_r.name("correlation matrix declaration");
       corr_matrix_decl_r 
-        %= lit("corr_matrix")
+        %= ( lit("corr_matrix")
+             >> no_skip[!char_("a-zA-Z0-9_")] )
         > lit('[')
         > expression_g(_r1)
           [validate_int_expr_f(_1,_pass,boost::phoenix::ref(error_msgs_))]
@@ -878,9 +900,9 @@ namespace stan {
       dims_r 
         %= lit('[') 
         > (expression_g(_r1)
-           [_pass = validate_int_data_expr_f(_1,
-                                             boost::phoenix::ref(var_map_),
-                                             boost::phoenix::ref(error_msgs_))]
+           [validate_int_data_expr_f(_1,_r1,_pass,
+                                     boost::phoenix::ref(var_map_),
+                                     boost::phoenix::ref(error_msgs_))]
            % ',')
         > lit(']')
         ;
