@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_COV_MATRIX_HPP__
-#define __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_COV_MATRIX_HPP__
+#ifndef STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_COV_MATRIX_HPP
+#define STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_COV_MATRIX_HPP
 
 #include <sstream>
 #include <stan/math/matrix/Eigen.hpp>
@@ -21,6 +21,7 @@ namespace stan {
      * @param name
      * @param result
      * @return <code>true</code> if the matrix is a valid covariance matrix.
+     * @return throws if any element in matrix is nan
      * @tparam T Type of scalar.
      */
     // FIXME: update warnings
