@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_MULTIPLICABLE_HPP__
-#define __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_MULTIPLICABLE_HPP__
+#ifndef STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_MULTIPLICABLE_HPP
+#define STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_MULTIPLICABLE_HPP
 
 #include <sstream>
 #include <stan/meta/traits.hpp>
@@ -10,6 +10,7 @@
 namespace stan {
   namespace math {
 
+    // NOTE: this will not throw if y1 or y2 contains nan values.
     template <typename T1, typename T2, typename T_result>
     inline bool check_multiplicable(const char* function,
                                     const T1& y1,
