@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_SIZE_MATCH_HPP__
-#define __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_SIZE_MATCH_HPP__
+#ifndef STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_SIZE_MATCH_HPP
+#define STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_SIZE_MATCH_HPP
 
 #include <sstream>
 #include <boost/type_traits/common_type.hpp>
