@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_SQUARE_HPP__
-#define __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_SQUARE_HPP__
+#ifndef STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_SQUARE_HPP
+#define STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_SQUARE_HPP
 
 #include <sstream>
 #include <stan/math/matrix/Eigen.hpp>
@@ -11,6 +11,8 @@ namespace stan {
     /**
      * Return <code>true</code> if the specified matrix is square.
      *
+     * NOTE: this will not throw if any elements in y are nan.
+     *
      * @param function
      * @param y Matrix to test.
      * @param name
