@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_STD_VECTOR_INDEX_HPP__
-#define __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_STD_VECTOR_INDEX_HPP__
+#ifndef STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_STD_VECTOR_INDEX_HPP
+#define STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_STD_VECTOR_INDEX_HPP
 
 #include <sstream>
 #include <vector>
@@ -11,6 +11,8 @@ namespace stan {
     /**
      * Return <code>true</code> if the specified index is valid in std vector
      *
+     * NOTE: this will not throw if y contains nan values.
+     *
      * @param function
      * @param i is index
      * @param y std vector to test against
