@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_VECTOR_HPP__
-#define __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_VECTOR_HPP__
+#ifndef STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_VECTOR_HPP
+#define STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_VECTOR_HPP
 
 #include <sstream>
 #include <stan/meta/traits.hpp>
@@ -9,6 +9,7 @@
 namespace stan {
   namespace math {
 
+    // NOTE: this will not throw if x contains nan values.
     template <typename T, int R, int C, typename T_result>
     inline bool check_vector(const char* function,
                              const Eigen::Matrix<T,R,C>& x,
