@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__ERROR_HANDLING__MATRIX__CONSTRAINT_TOLERANCE_HPP__
-#define __STAN__MATH__ERROR_HANDLING__MATRIX__CONSTRAINT_TOLERANCE_HPP__
+#ifndef STAN__MATH__ERROR_HANDLING__MATRIX__CONSTRAINT_TOLERANCE_HPP
+#define STAN__MATH__ERROR_HANDLING__MATRIX__CONSTRAINT_TOLERANCE_HPP
 
 namespace stan {
   namespace math {
