@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__ERROR_HANDLING__MATRIX__VALIDATE_NON_NEGATIVE_INDEX_HPP__
-#define __STAN__MATH__ERROR_HANDLING__MATRIX__VALIDATE_NON_NEGATIVE_INDEX_HPP__
+#ifndef STAN__MATH__ERROR_HANDLING__MATRIX__VALIDATE_NON_NEGATIVE_INDEX_HPP
+#define STAN__MATH__ERROR_HANDLING__MATRIX__VALIDATE_NON_NEGATIVE_INDEX_HPP
 
 #include <sstream>
 #include <stdexcept>
