@@ -1,11 +1,13 @@
-#ifndef __STAN__MATH__MATRIX__MDIVIDE_RIGHT_SPD_HPP__
-#define __STAN__MATH__MATRIX__MDIVIDE_RIGHT_SPD_HPP__
+#ifndef STAN__MATH__MATRIX__MDIVIDE_RIGHT_SPD_HPP
+#define STAN__MATH__MATRIX__MDIVIDE_RIGHT_SPD_HPP
 
 #include <boost/math/tools/promotion.hpp>
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/mdivide_left_spd.hpp>
 #include <stan/math/matrix/transpose.hpp>
 #include <stan/math/error_handling/matrix/check_multiplicable.hpp>
+#include <stan/math/error_handling/matrix/check_pos_definite.hpp>
+#include <stan/math/error_handling/matrix/check_symmetric.hpp>
 #include <stan/math/error_handling/matrix/check_square.hpp>
 
 namespace stan {
@@ -25,6 +27,8 @@ namespace stan {
     Eigen::Matrix<typename boost::math::tools::promote_args<T1,T2>::type,R1,C2>
     mdivide_right_spd(const Eigen::Matrix<T1,R1,C1> &b,
                       const Eigen::Matrix<T2,R2,C2> &A) {
+      stan::math::check_symmetric("mdivide_right_spd(%1%)",A,"A",(double*)0);
+      stan::math::check_pos_definite("mdivide_right_spd(%1%)",A,"A",(double*)0);
       stan::math::check_square("mdivide_right_spd(%1%)",A,"A",(double*)0);
       stan::math::check_multiplicable("mdivide_right_spd(%1%)",b,"b",
                                       A,"A",(double*)0);
