@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__MATRIX__MULTIPLY_HPP__
-#define __STAN__MATH__MATRIX__MULTIPLY_HPP__
+#ifndef STAN__MATH__MATRIX__MULTIPLY_HPP
+#define STAN__MATH__MATRIX__MULTIPLY_HPP
 
 #include <boost/type_traits/is_arithmetic.hpp> 
 #include <boost/utility/enable_if.hpp>
