@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__MATRIX__QR_Q_HPP__
-#define __STAN__MATH__MATRIX__QR_Q_HPP__
+#ifndef STAN__MATH__MATRIX__QR_Q_HPP
+#define STAN__MATH__MATRIX__QR_Q_HPP
 
 #include <stan/math/error_handling/check_greater_or_equal.hpp>
 #include <stan/math/error_handling/matrix/check_nonzero_size.hpp>
