@@ -1,5 +1,5 @@
-#ifndef __STAN__PROB__DISTRIBUTIONS__MULTIVARIATE__CONTINUOUS__MULTI_NORMAL_HPP__
-#define __STAN__PROB__DISTRIBUTIONS__MULTIVARIATE__CONTINUOUS__MULTI_NORMAL_HPP__
+#ifndef STAN__PROB__DISTRIBUTIONS__MULTIVARIATE__CONTINUOUS__MULTI_NORMAL_HPP
+#define STAN__PROB__DISTRIBUTIONS__MULTIVARIATE__CONTINUOUS__MULTI_NORMAL_HPP
 
 #include <boost/random/normal_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
@@ -27,19 +27,18 @@ namespace stan {
     multi_normal_log(const T_y& y,
                      const T_loc& mu,
                      const Eigen::Matrix<T_covar,Eigen::Dynamic,Eigen::Dynamic>& Sigma) {
-      
       static const char* function = "stan::prob::multi_normal_log(%1%)";
       typedef typename boost::math::tools::promote_args<typename scalar_type<T_y>::type, typename scalar_type<T_loc>::type, T_covar>::type lp_type;
       lp_type lp(0.0);
       
-      using stan::math::check_not_nan;
       using stan::math::check_size_match;
-      using stan::math::check_positive;
       using stan::math::check_finite;
+      using stan::math::check_not_nan;
+      using stan::math::check_positive;
       using stan::math::check_symmetric;
-      using stan::math::check_ldlt_factor;     
-             
-      check_size_match(function, 
+      using stan::math::check_ldlt_factor;
+
+      check_size_match(function,
                             Sigma.rows(), "Rows of covariance parameter",
                             Sigma.cols(), "columns of covariance parameter",
                             &lp);
@@ -48,16 +47,12 @@ namespace stan {
       
       stan::math::LDLT_factor<T_covar,Eigen::Dynamic,Eigen::Dynamic> ldlt_Sigma(Sigma);
       check_ldlt_factor(function,ldlt_Sigma,"LDLT_Factor of covariance parameter",&lp);
-        
-      using Eigen::Matrix;
-      using Eigen::Dynamic;
-      using std::vector;
+
       VectorViewMvt<const T_y> y_vec(y);
       VectorViewMvt<const T_loc> mu_vec(mu);
       //size of std::vector of Eigen vectors
       size_t size_vec = max_size_mvt(y, mu);
-      
-      
+
       //Check if every vector of the array has the same size
       int size_y = y_vec[0].size();
       int size_mu = mu_vec[0].size();
@@ -101,27 +96,26 @@ namespace stan {
                             Sigma.cols(), "columns of covariance parameter",
                             &lp);
   
-      for (size_t i = 0; i < size_vec; i++) {      
+      for (size_t i = 0; i < size_vec; i++) {
         check_finite(function, mu_vec[i], "Location parameter", &lp);
         check_not_nan(function, y_vec[i], "Random variable", &lp);
-      } 
+      }
       
       if (size_y == 0) //y_vec[0].size() == 0
         return lp;
 
+      if (include_summand<propto>::value) 
+        lp += NEG_LOG_SQRT_TWO_PI * size_y * size_vec;
 
       if (include_summand<propto, T_covar>::value)
         lp -= 0.5 * log_determinant_ldlt(ldlt_Sigma) * size_vec;
 
-      if (include_summand<propto>::value) 
-        lp += NEG_LOG_SQRT_TWO_PI * size_y * size_vec;
-          
       if (include_summand<propto,T_y,T_loc,T_covar>::value) {
         lp_type sum_lp_vec(0.0);
         for (size_t i = 0; i < size_vec; i++) {
-          Matrix<typename 
+          Eigen::Matrix<typename 
               boost::math::tools::promote_args<typename scalar_type<T_y>::type, typename scalar_type<T_loc>::type>::type,
-              Dynamic, 1> y_minus_mu(size_y);
+              Eigen::Dynamic, 1> y_minus_mu(size_y);
           for (int j = 0; j < size_y; j++)
             y_minus_mu(j) = y_vec[i](j)-mu_vec[i](j);
           sum_lp_vec += trace_inv_quad_form_ldlt(ldlt_Sigma,y_minus_mu);
@@ -150,8 +144,8 @@ namespace stan {
 
       static const char* function = "stan::prob::multi_normal_rng(%1%)";
 
-      using stan::math::check_positive;
       using stan::math::check_finite;
+      using stan::math::check_positive;
       using stan::math::check_symmetric;
  
       check_positive(function, S.rows(), "Covariance matrix rows", (double*)0);
@@ -171,4 +165,3 @@ namespace stan {
 }
 
 #endif
-
