@@ -1,5 +1,5 @@
-#ifndef __STAN__PROB__DISTRIBUTIONS__UNIVARIATE__CONTINUOUS__CHI_SQUARE_HPP__
-#define __STAN__PROB__DISTRIBUTIONS__UNIVARIATE__CONTINUOUS__CHI_SQUARE_HPP__
+#ifndef STAN__PROB__DISTRIBUTIONS__UNIVARIATE__CONTINUOUS__CHI_SQUARE_HPP
+#define STAN__PROB__DISTRIBUTIONS__UNIVARIATE__CONTINUOUS__CHI_SQUARE_HPP
 
 #include <boost/random/chi_squared_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
@@ -48,8 +48,7 @@ namespace stan {
             && stan::length(nu)))
         return 0.0;
       
-      using stan::math::check_positive;
-      using stan::math::check_finite;
+      using stan::math::check_positive_finite;
       using stan::math::check_nonnegative;
       using stan::math::check_not_nan;
       using stan::math::check_consistent_sizes;
@@ -58,8 +57,8 @@ namespace stan {
       double logp(0.0);
       check_not_nan(function, y, "Random variable", &logp);
       check_nonnegative(function, y, "Random variable", &logp);
-      check_finite(function, nu, "Degrees of freedom parameter", &logp);
-      check_positive(function, nu, "Degrees of freedom parameter", &logp);
+      check_positive_finite(function, nu, "Degrees of freedom parameter",
+                            &logp);
       check_consistent_sizes(function,
                              y,nu,
                              "Random variable","Degrees of freedom parameter",
@@ -155,8 +154,7 @@ namespace stan {
     chi_square_cdf(const T_y& y, const T_dof& nu) {
       static const char* function = "stan::prob::chi_square_cdf(%1%)";
 
-      using stan::math::check_positive;
-      using stan::math::check_finite;
+      using stan::math::check_positive_finite;
       using stan::math::check_nonnegative;
       using stan::math::check_not_nan;
       using stan::math::check_consistent_sizes;
@@ -170,8 +168,7 @@ namespace stan {
 
       check_not_nan(function, y, "Random variable", &cdf);
       check_nonnegative(function, y, "Random variable", &cdf);
-      check_finite(function, nu, "Degrees of freedom parameter", &cdf);
-      check_positive(function, nu, "Degrees of freedom parameter", &cdf);
+      check_positive_finite(function, nu, "Degrees of freedom parameter", &cdf);
       check_consistent_sizes(function,
                              y,nu,
                              "Random variable","Degrees of freedom parameter",
@@ -257,8 +254,7 @@ namespace stan {
     chi_square_cdf_log(const T_y& y, const T_dof& nu) {
       static const char* function = "stan::prob::chi_square_cdf_log(%1%)";
 
-      using stan::math::check_positive;
-      using stan::math::check_finite;
+      using stan::math::check_positive_finite;
       using stan::math::check_nonnegative;
       using stan::math::check_not_nan;
       using stan::math::check_consistent_sizes;
@@ -272,8 +268,8 @@ namespace stan {
 
       check_not_nan(function, y, "Random variable", &cdf_log);
       check_nonnegative(function, y, "Random variable", &cdf_log);
-      check_finite(function, nu, "Degrees of freedom parameter", &cdf_log);
-      check_positive(function, nu, "Degrees of freedom parameter", &cdf_log);
+      check_positive_finite(function, nu, "Degrees of freedom parameter", 
+                            &cdf_log);
       check_consistent_sizes(function,
                              y,nu,
                              "Random variable","Degrees of freedom parameter",
@@ -352,8 +348,7 @@ namespace stan {
     chi_square_ccdf_log(const T_y& y, const T_dof& nu) {
       static const char* function = "stan::prob::chi_square_ccdf_log(%1%)";
 
-      using stan::math::check_positive;
-      using stan::math::check_finite;
+      using stan::math::check_positive_finite;
       using stan::math::check_nonnegative;
       using stan::math::check_not_nan;
       using stan::math::check_consistent_sizes;
@@ -367,8 +362,8 @@ namespace stan {
 
       check_not_nan(function, y, "Random variable", &ccdf_log);
       check_nonnegative(function, y, "Random variable", &ccdf_log);
-      check_finite(function, nu, "Degrees of freedom parameter", &ccdf_log);
-      check_positive(function, nu, "Degrees of freedom parameter", &ccdf_log);
+      check_positive_finite(function, nu, "Degrees of freedom parameter",
+                            &ccdf_log);
       check_consistent_sizes(function,
                              y,nu,
                              "Random variable","Degrees of freedom parameter",
@@ -451,11 +446,10 @@ namespace stan {
 
       static const char* function = "stan::prob::chi_square_rng(%1%)";
 
-      using stan::math::check_positive;
-      using stan::math::check_finite;
+      using stan::math::check_positive_finite;
       
-      check_finite(function, nu, "Degrees of freedom parameter", (double*)0);
-      check_positive(function, nu, "Degrees of freedom parameter", (double*)0);
+      check_positive_finite(function, nu, "Degrees of freedom parameter", 
+                            (double*)0);
     
 
       variate_generator<RNG&, chi_squared_distribution<> >
