@@ -1,5 +1,5 @@
-#ifndef __STAN__PROB__DISTRIBUTIONS__UNIVARIATE__CONTINUOUS__STUDENT_T_HPP__
-#define __STAN__PROB__DISTRIBUTIONS__UNIVARIATE__CONTINUOUS__STUDENT_T_HPP__
+#ifndef STAN__PROB__DISTRIBUTIONS__UNIVARIATE__CONTINUOUS__STUDENT_T_HPP
+#define STAN__PROB__DISTRIBUTIONS__UNIVARIATE__CONTINUOUS__STUDENT_T_HPP
 
 #include <boost/random/student_t_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
@@ -50,7 +50,7 @@ namespace stan {
                   const T_scale& sigma) {
       static const char* function = "stan::prob::student_t_log(%1%)";
 
-      using stan::math::check_positive;
+      using stan::math::check_positive_finite;
       using stan::math::check_finite;
       using stan::math::check_not_nan;
       using stan::math::check_consistent_sizes;
@@ -66,11 +66,10 @@ namespace stan {
 
       // validate args (here done over var, which should be OK)
       check_not_nan(function, y, "Random variable", &logp);
-      check_finite(function, nu, "Degrees of freedom parameter", &logp);
-      check_positive(function, nu, "Degrees of freedom parameter", &logp);
+      check_positive_finite(function, nu, "Degrees of freedom parameter",
+                            &logp);
       check_finite(function, mu, "Location parameter", &logp);
-      check_finite(function, sigma, "Scale parameter", &logp);
-      check_positive(function, sigma, "Scale parameter", &logp);
+      check_positive_finite(function, sigma, "Scale parameter", &logp);
       check_consistent_sizes(function,
                              y,nu,mu,sigma,
                              "Random variable",
@@ -227,7 +226,7 @@ namespace stan {
       
       static const char* function = "stan::prob::student_t_cdf(%1%)";
           
-      using stan::math::check_positive;
+      using stan::math::check_positive_finite;
       using stan::math::check_finite;
       using stan::math::check_not_nan;
       using stan::math::check_consistent_sizes;
@@ -236,11 +235,9 @@ namespace stan {
       double P(1.0);
           
       check_not_nan(function, y, "Random variable", &P);
-      check_finite(function, nu, "Degrees of freedom parameter", &P);
-      check_positive(function, nu, "Degrees of freedom parameter", &P);
+      check_positive_finite(function, nu, "Degrees of freedom parameter", &P);
       check_finite(function, mu, "Location parameter", &P);
-      check_finite(function, sigma, "Scale parameter", &P);
-      check_positive(function, sigma, "Scale parameter", &P);
+      check_positive_finite(function, sigma, "Scale parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -403,7 +400,7 @@ namespace stan {
       
       static const char* function = "stan::prob::student_t_cdf_log(%1%)";
           
-      using stan::math::check_positive;
+      using stan::math::check_positive_finite;
       using stan::math::check_finite;
       using stan::math::check_not_nan;
       using stan::math::check_consistent_sizes;
@@ -412,11 +409,9 @@ namespace stan {
       double P(0.0);
           
       check_not_nan(function, y, "Random variable", &P);
-      check_finite(function, nu, "Degrees of freedom parameter", &P);
-      check_positive(function, nu, "Degrees of freedom parameter", &P);
+      check_positive_finite(function, nu, "Degrees of freedom parameter", &P);
       check_finite(function, mu, "Location parameter", &P);
-      check_finite(function, sigma, "Scale parameter", &P);
-      check_positive(function, sigma, "Scale parameter", &P);
+      check_positive_finite(function, sigma, "Scale parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -567,7 +562,7 @@ namespace stan {
       
       static const char* function = "stan::prob::student_t_ccdf_log(%1%)";
           
-      using stan::math::check_positive;
+      using stan::math::check_positive_finite;
       using stan::math::check_finite;
       using stan::math::check_not_nan;
       using stan::math::check_consistent_sizes;
@@ -576,11 +571,9 @@ namespace stan {
       double P(0.0);
           
       check_not_nan(function, y, "Random variable", &P);
-      check_finite(function, nu, "Degrees of freedom parameter", &P);
-      check_positive(function, nu, "Degrees of freedom parameter", &P);
+      check_positive_finite(function, nu, "Degrees of freedom parameter", &P);
       check_finite(function, mu, "Location parameter", &P);
-      check_finite(function, sigma, "Scale parameter", &P);
-      check_positive(function, sigma, "Scale parameter", &P);
+      check_positive_finite(function, sigma, "Scale parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -730,14 +723,13 @@ namespace stan {
 
       static const char* function = "stan::prob::student_t_rng(%1%)";
 
-      using stan::math::check_positive;
+      using stan::math::check_positive_finite;
       using stan::math::check_finite;
 
-      check_finite(function, nu, "Degrees of freedom parameter", (double*)0);
-      check_positive(function, nu, "Degrees of freedom parameter", (double*)0);
+      check_positive_finite(function, nu, "Degrees of freedom parameter",
+                            (double*)0);
       check_finite(function, mu, "Location parameter", (double*)0);
-      check_finite(function, sigma, "Scale parameter", (double*)0); 
-      check_positive(function, sigma, "Scale parameter", (double*)0);
+      check_positive_finite(function, sigma, "Scale parameter", (double*)0); 
 
       variate_generator<RNG&, student_t_distribution<> >
         rng_unit_student_t(rng, student_t_distribution<>(nu));
