@@ -1,5 +1,5 @@
-#ifndef __STAN__PROB__TRANSFORM_HPP__
-#define __STAN__PROB__TRANSFORM_HPP__
+#ifndef STAN__PROB__TRANSFORM_HPP
+#define STAN__PROB__TRANSFORM_HPP
 
 #include <cmath>
 #include <cstddef>
@@ -7,16 +7,22 @@
 #include <stdexcept>
 #include <sstream>
 #include <vector>
+
 #include <boost/throw_exception.hpp>
 #include <boost/math/tools/promotion.hpp>
+
 #include <stan/agrad/rev/matrix.hpp>
+
 #include <stan/math.hpp>
 #include <stan/math/error_handling.hpp>
 #include <stan/math/error_handling/matrix/check_square.hpp>
 #include <stan/math/matrix.hpp>
+
 #include <stan/math/matrix/sum.hpp>
 #include <stan/math/matrix_error_handling.hpp>
 #include <stan/math/matrix/multiply_lower_tri_self_transpose.hpp>
+#include <stan/math/matrix/meta/index_type.hpp>
+
 
 namespace stan {
   
@@ -335,16 +341,19 @@ namespace stan {
     template<typename T>
     const Eigen::Array<T,Eigen::Dynamic,1>
     make_nu(const T eta, const size_t K) {
+      using Eigen::Array;
+      using Eigen::Dynamic;
+      using Eigen::Matrix;
+      using stan::math::index_type;
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
   
-      Eigen::Array<T,Eigen::Dynamic,1> nu(K * (K - 1) / 2);
+      Array<T,Dynamic,1> nu(K * (K - 1) / 2);
   
       T alpha = eta + (K - 2.0) / 2.0; // from Lewandowski et. al.
 
       // Best (1978) implies nu = 2 * alpha for the dof in a t 
       // distribution that generates a beta variate on (-1,1)
       T alpha2 = 2.0 * alpha; 
-
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
       for (size_type j = 0; j < (K - 1); j++) {
         nu(j) = alpha2;
       }
@@ -1004,9 +1013,12 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,1> 
     unit_vector_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& y) {
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+      using Eigen::Matrix;
+      using Eigen::Dynamic;
+      using stan::math::index_type;
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
       int Km1 = y.size();
-      Eigen::Matrix<T,Eigen::Dynamic,1> x(Km1 + 1);
+      Matrix<T,Dynamic,1> x(Km1 + 1);
       x(0) = 1.0;
       const T half_pi = T(M_PI/2.0);
       for (size_type k = 1; k <= Km1; ++k) {
@@ -1030,18 +1042,22 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,1> 
     unit_vector_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& y, T &lp) {
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+      using Eigen::Matrix;
+      using Eigen::Dynamic;
+      using stan::math::index_type;
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+
       int Km1 = y.size();
-      Eigen::Matrix<T,Eigen::Dynamic,1> x(Km1 + 1);
+      Matrix<T,Dynamic,1> x(Km1 + 1);
       x(0) = 1.0;
-      const T half_pi = T(M_PI/2.0);
+      const T half_pi = T(0.5 * M_PI);
       for (size_type k = 1; k <= Km1; ++k) {
         T yk_1 = y(k-1) + half_pi;
         T sin_yk_1 = sin(yk_1);
-        x(k) = x(k-1)*sin_yk_1; 
+        x(k) = x(k-1) * sin_yk_1; 
         x(k-1) *= cos(yk_1);
         if (k < Km1)
-          lp += (Km1 - k)*log(fabs(sin_yk_1));
+          lp += (Km1 - k) * log(fabs(sin_yk_1));
       }
       return x;
     }
@@ -1049,11 +1065,15 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,1> 
     unit_vector_free(const Eigen::Matrix<T,Eigen::Dynamic,1>& x) {
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+      using Eigen::Matrix;
+      using Eigen::Dynamic;
+      using stan::math::index_type;
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+
       stan::math::check_unit_vector("stan::prob::unit_vector_free(%1%)", 
                                     x, "Unit vector variable", (double*)0);
       int Km1 = x.size() - 1;
-      Eigen::Matrix<T,Eigen::Dynamic,1> y(Km1);
+      Matrix<T,Dynamic,1> y(Km1);
       T sumSq = x(Km1)*x(Km1);
       const T half_pi = T(M_PI/2.0);
       for (size_type k = Km1; --k >= 0; ) {
@@ -1063,8 +1083,8 @@ namespace stan {
       return y;
     }
 
-    // SIMPLEX
 
+    // SIMPLEX
 
     /**
      * Return the simplex corresponding to the specified free vector.  
@@ -1081,13 +1101,19 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,1> 
     simplex_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& y) {
+
       // cut & paste simplex_constrain(Eigen::Matrix,T) w/o Jacobian
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
-      using stan::math::logit;
+      using Eigen::Matrix;
+      using Eigen::Dynamic;
+      using stan::math::index_type;
       using stan::math::inv_logit;
+      using stan::math::logit;
       using stan::math::log1m;
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+
+
       int Km1 = y.size();
-      Eigen::Matrix<T,Eigen::Dynamic,1> x(Km1 + 1);
+      Matrix<T,Dynamic,1> x(Km1 + 1);
       T stick_len(1.0);
       for (size_type k = 0; k < Km1; ++k) {
         T z_k(inv_logit(y(k) - log(Km1 - k))); 
@@ -1115,13 +1141,19 @@ namespace stan {
     Eigen::Matrix<T,Eigen::Dynamic,1> 
     simplex_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& y, 
                       T& lp) {
-      using stan::math::logit;
+
+      using Eigen::Dynamic;
+      using Eigen::Matrix;
+      using stan::math::index_type;
       using stan::math::inv_logit;
-      using stan::math::log1p_exp;
+      using stan::math::logit;
       using stan::math::log1m;
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+      using stan::math::log1p_exp;
+
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+
       int Km1 = y.size(); // K = Km1 + 1
-      Eigen::Matrix<T,Eigen::Dynamic,1> x(Km1 + 1);
+      Matrix<T,Dynamic,1> x(Km1 + 1);
       T stick_len(1.0);
       for (size_type k = 0; k < Km1; ++k) {
         double eq_share = -log(Km1 - k); // = logit(1.0/(Km1 + 1 - k));
@@ -1154,8 +1186,13 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,1> 
     simplex_free(const Eigen::Matrix<T,Eigen::Dynamic,1>& x) {
+      using Eigen::Dynamic;
+      using Eigen::Matrix;
+      using stan::math::index_type;
       using stan::math::logit;
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+
       stan::math::check_simplex("stan::prob::simplex_free(%1%)", x, "Simplex variable",
                                 (double*)0);
       int Km1 = x.size() - 1;
@@ -1185,15 +1222,18 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,1> 
     ordered_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& x) {
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+      using Eigen::Matrix;
+      using Eigen::Dynamic;
+      using stan::math::index_type;
+
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+
       size_type k = x.size();
-      Eigen::Matrix<T,Eigen::Dynamic,1> y(k);
+      Matrix<T,Dynamic,1> y(k);
       if (k == 0)
         return y;
       y[0] = x[0];
-      for (size_type i = 1; 
-           i < k; 
-           ++i)
+      for (size_type i = 1; i < k; ++i)
         y[i] = y[i-1] + exp(x[i]);
       return y;
     }
@@ -1214,7 +1254,12 @@ namespace stan {
     inline
     Eigen::Matrix<T,Eigen::Dynamic,1> 
     ordered_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& x, T& lp) {
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+      using Eigen::Matrix;
+      using Eigen::Dynamic;
+      using stan::math::index_type;
+
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+
       for (size_type i = 1; i < x.size(); ++i)
         lp += x(i);
       return ordered_constrain(x);
@@ -1240,9 +1285,13 @@ namespace stan {
     ordered_free(const Eigen::Matrix<T,Eigen::Dynamic,1>& y) {
       stan::math::check_ordered("stan::prob::ordered_free(%1%)", 
                                 y, "Ordered variable");
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+      using Eigen::Matrix;
+      using Eigen::Dynamic;
+      using stan::math::index_type;
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+
       size_type k = y.size();
-      Eigen::Matrix<T,Eigen::Dynamic,1> x(k);
+      Matrix<T,Dynamic,1> x(k);
       if (k == 0) 
         return x;
       x[0] = y[0];
@@ -1266,15 +1315,17 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,1> 
     positive_ordered_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& x) {
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+      using Eigen::Matrix;
+      using Eigen::Dynamic;
+      using stan::math::index_type;
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+
       size_type k = x.size();
-      Eigen::Matrix<T,Eigen::Dynamic,1> y(k);
+      Matrix<T,Dynamic,1> y(k);
       if (k == 0)
         return y;
       y[0] = exp(x[0]);
-      for (size_type i = 1; 
-           i < k; 
-           ++i)
+      for (size_type i = 1; i < k; ++i)
         y[i] = y[i-1] + exp(x[i]);
       return y;
     }
@@ -1295,7 +1346,11 @@ namespace stan {
     inline
     Eigen::Matrix<T,Eigen::Dynamic,1> 
     positive_ordered_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& x, T& lp) {
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+      using Eigen::Matrix;
+      using Eigen::Dynamic;
+      using stan::math::index_type;
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+
       for (size_type i = 0; i < x.size(); ++i)
         lp += x(i);
       return positive_ordered_constrain(x);
@@ -1319,11 +1374,17 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,1> 
     positive_ordered_free(const Eigen::Matrix<T,Eigen::Dynamic,1>& y) {
+      using Eigen::Matrix;
+      using Eigen::Dynamic;
+      using stan::math::index_type;
+
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+
       stan::math::check_positive_ordered("stan::prob::positive_ordered_free(%1%)", 
                                          y, "Positive ordered variable", (double*)0);
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+
       size_type k = y.size();
-      Eigen::Matrix<T,Eigen::Dynamic,1> x(k);
+      Matrix<T,Dynamic,1> x(k);
       if (k == 0) 
         return x;
       x[0] = log(y[0]);
@@ -1355,7 +1416,8 @@ namespace stan {
       if (M < N)
         throw std::domain_error("cholesky_factor_constrain: num rows must be >= num cols");
       if (x.size() != ((N * (N + 1)) / 2 + (M - N) * N))
-        throw std::domain_error("cholesky_factor_constrain: x.size() must be (N * (N + 1)) / 2 + (M - N) * N");
+        throw std::domain_error("cholesky_factor_constrain: x.size() must"
+                                " be (N * (N + 1)) / 2 + (M - N) * N");
       Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic> y(M,N);
       T zero(0);
       int pos = 0;
@@ -1580,8 +1642,13 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic> 
     corr_matrix_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& x,
-                 typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type k) {
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+                  typename math::index_type<Eigen::Matrix<T,Eigen::Dynamic,1> >::type k) {
+
+      using Eigen::Dynamic;
+      using Eigen::Matrix;
+      using stan::math::index_type;
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+
       size_type k_choose_2 = (k * (k - 1)) / 2;
       if (k_choose_2 != x.size())
         throw std::invalid_argument ("x is not a valid correlation matrix");
@@ -1613,13 +1680,18 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic> 
     corr_matrix_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& x, 
-                    typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type k,
-                    T& lp) {
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+                  typename math::index_type<Eigen::Matrix<T,Eigen::Dynamic,1> >::type k,
+                  T& lp) {
+      using Eigen::Array;
+      using Eigen::Dynamic;
+      using Eigen::Matrix;
+      using stan::math::index_type;
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+  
       size_type k_choose_2 = (k * (k - 1)) / 2;
       if (k_choose_2 != x.size())
         throw std::invalid_argument ("x is not a valid correlation matrix");
-      Eigen::Array<T,Eigen::Dynamic,1> cpcs(k_choose_2);
+      Array<T,Dynamic,1> cpcs(k_choose_2);
       for (size_type i = 0; i < k_choose_2; ++i)
         cpcs[i] = corr_constrain(x[i],lp);
       return read_corr_matrix(cpcs,k,lp);
@@ -1648,16 +1720,20 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,1> 
     corr_matrix_free(const Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>& y) {
-      typedef typename 
-        Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>::size_type size_type;
+      using Eigen::Array;
+      using Eigen::Dynamic;
+      using Eigen::Matrix;
+      using stan::math::index_type;
+      typedef typename index_type<Matrix<T,Dynamic,1> >::type size_type;
+
       size_type k = y.rows();
       if (y.cols() != k)
         throw std::domain_error("y is not a square matrix");
       if (k == 0)
         throw std::domain_error("y has no elements");
       size_type k_choose_2 = (k * (k-1)) / 2;
-      Eigen::Array<T,Eigen::Dynamic,1> x(k_choose_2);
-      Eigen::Array<T,Eigen::Dynamic,1> sds(k);
+      Array<T,Dynamic,1> x(k_choose_2);
+      Array<T,Dynamic,1> sds(k);
       bool successful = factor_cov_matrix(y,x,sds);
       if (!successful)
         throw std::runtime_error("factor_cov_matrix failed on y");
@@ -1691,10 +1767,16 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic> 
     cov_matrix_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& x, 
-                         typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type K) {
+                 typename math::index_type<Eigen::Matrix<T,Eigen::Dynamic,1> >::type K) {
       using std::exp;
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
-      Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic> L(K,K);
+
+      using Eigen::Dynamic;
+      using Eigen::Matrix;
+      using stan::math::index_type;
+      using stan::math::multiply_lower_tri_self_transpose;
+      typedef typename index_type<Matrix<T,Dynamic,Dynamic> >::type size_type;
+
+      Matrix<T,Dynamic,Dynamic> L(K,K);
       if (x.size() != (K * (K + 1)) / 2) 
         throw std::domain_error("x.size() != K + (K choose 2)");
       int i = 0;
@@ -1705,7 +1787,6 @@ namespace stan {
         for (size_type n = m + 1; n < K; ++n) 
           L(m,n) = 0.0;
       }
-      using stan::math::multiply_lower_tri_self_transpose;
       return multiply_lower_tri_self_transpose(L); 
     }
 
@@ -1725,13 +1806,20 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic> 
     cov_matrix_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& x, 
-                         typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type K,
-                         T& lp) {
+         typename math::index_type<Eigen::Matrix<T,
+                                                 Eigen::Dynamic,
+                                                 Eigen::Dynamic> >::type K,
+         T& lp) {
       using std::exp;
-      typedef typename Eigen::Matrix<T,Eigen::Dynamic,1>::size_type size_type;
+
+      using Eigen::Dynamic;
+      using Eigen::Matrix;
+      using stan::math::index_type;
+      typedef typename index_type<Matrix<T,Dynamic,Dynamic> >::type size_type;
+
       if (x.size() != (K * (K + 1)) / 2) 
         throw std::domain_error("x.size() != K + (K choose 2)");
-      Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic> L(K,K);
+      Matrix<T,Dynamic,Dynamic> L(K,K);
       int i = 0;
       for (size_type m = 0; m < K; ++m) {
         for (size_type n = 0; n < m; ++n)
@@ -1894,20 +1982,25 @@ namespace stan {
     Eigen::Matrix<T,Eigen::Dynamic,1> 
     cov_matrix_free_lkj(
             const Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>& y) {
-      typedef typename
-        Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>::size_type size_type;
+
+      using Eigen::Array;
+      using Eigen::Dynamic;
+      using Eigen::Matrix;
+      using stan::math::index_type;
+      typedef typename index_type<Matrix<T,Dynamic,Dynamic> >::type size_type;
+
       size_type k = y.rows();
       if (y.cols() != k)
         throw std::domain_error("y is not a square matrix");
       if (k == 0)
         throw std::domain_error("y has no elements");
       size_type k_choose_2 = (k * (k-1)) / 2;
-      Eigen::Array<T,Eigen::Dynamic,1> cpcs(k_choose_2);
-      Eigen::Array<T,Eigen::Dynamic,1> sds(k);
+      Array<T,Dynamic,1> cpcs(k_choose_2);
+      Array<T,Dynamic,1> sds(k);
       bool successful = factor_cov_matrix(y,cpcs,sds);
       if (!successful)
         throw std::runtime_error ("factor_cov_matrix failed on y");
-      Eigen::Matrix<T,Eigen::Dynamic,1> x(k_choose_2 + k);
+      Matrix<T,Dynamic,1> x(k_choose_2 + k);
       size_type pos = 0;
       for (size_type i = 0; i < k_choose_2; ++i)
         x[pos++] = cpcs[i];
