@@ -15,6 +15,8 @@
 #include <boost/random/additive_combine.hpp> // L'Ecuyer RNG
 #include <boost/random/uniform_real_distribution.hpp>
 
+#include <stan/agrad/rev/var_stack_def.hpp>
+
 #include <stan/model/util.hpp>
 
 #include <stan/optimization/newton.hpp>
@@ -877,7 +879,6 @@ namespace pystan {
       std::vector<double> params_inr_etc; // cont, disc, and others
       std::vector<double> init_grad;
       std::string init_val = args.get_init();
-      double init_log_prob;
       int num_init_tries = 0;
       PyErr_CheckSignals_Functor interruptCallback;
       // parameter initialization
